@@ -71,17 +71,18 @@ sub patron_id {
     return $self->user_id;
 }
 
+sub patron {
+    my $self = shift;
+    return {id => $self->user_id};
+}
 
 =head1 NATIVE METHODS
 
 =head2 native_patron ()
 
-=cut
+This method cannot be called
 
-sub native_patron {
-    my $self = shift;
-    return $self->SUPER::native_patron($self->user_id)
-}
+=cut
 
 1;
 
